Type Alias Result

pub type Result<T> = Result<T, TensorError>;
Error types and Result alias for the library A type alias for Result<T, TensorError>.

This is the standard result type used throughout the tensor library.

Aliased Type

pub enum Result<T> {
    Ok(T),
    Err(TensorError),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(TensorError)

Contains the error value